%define upstream_name    Proc-Fork
%define upstream_version 0.808

%{?perl_default_filter}

Name:       perl-%{upstream_name}
Version:    %perl_convert_version %{upstream_version}
Release:    %mkrel 1

Summary:    Simple, intuitive interface to fork()
License:    GPL+ or Artistic
Group:      Development/Perl
Url:        https://metacpan.org/release/%{upstream_name}
Source0:    https://cpan.metacpan.org/modules/by-module/Proc/%{upstream_name}-%{upstream_version}.tar.gz

BuildRequires: perl(Carp)
BuildRequires: perl(Exporter::Tidy)
BuildArch:  noarch

%description
This module provides an intuitive, Perl-ish way to write forking programs
by letting you use blocks to illustrate which code section executes in
which fork. The code for the parent, child, retry handler and error handler
are grouped together in a "fork block". The clauses may appear in any
order, but they must be consecutive (without any other statements in
between).

All four clauses need not be specified. If the retry clause is omitted,
only one fork will be attempted. If the error clause is omitted the program
will die with a simple message if it can't retry. If the parent or child
clause is omitted, the respective (parent or child) process will start
execution after the final clause. So if one or the other only has to do
some simple action, you need only specify that one. For example:

 # spawn off a child process to do some simple processing
 run_fork { child {
     exec '/bin/ls', '-l';
     die "Couldn't exec ls: $!\n";
 } };
 # Parent will continue execution from here
 # ...

%prep
%setup -q -n %{upstream_name}-%{upstream_version}

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor

%make_build

%check
%make_build test

%install
%make_install

%files
%doc Changes LICENSE META.json META.yml MYMETA.yml README eg
%{_mandir}/man3/*
%perl_vendorlib/*

%changelog
* Mon Sep 05 2022 tv <tv> 0.808.0-1.mga9
+ Revision: 1884076
- update to 0.808

* Sat Aug 13 2022 tv <tv> 0.807.0-1.mga9
+ Revision: 1877359
- update to 0.807

* Mon Mar 21 2022 umeabot <umeabot> 0.806.0-4.mga9
+ Revision: 1810106
- Mageia 9 Mass Rebuild

* Wed Feb 12 2020 umeabot <umeabot> 0.806.0-3.mga8
+ Revision: 1506078
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%makeinstall_std

* Thu Sep 20 2018 umeabot <umeabot> 0.806.0-2.mga7
+ Revision: 1285840
- Mageia 7 Mass Rebuild

* Sat Aug 25 2018 shlomif <shlomif> 0.806.0-1.mga7
+ Revision: 1253973
- update to 0.806

* Sun Jun 19 2016 pterjan <pterjan> 0.804.0-3.mga6
+ Revision: 1032699
- Rebuild for perl 5.22.2

* Thu Feb 18 2016 umeabot <umeabot> 0.804.0-2.mga6
+ Revision: 966830
- Mageia 6 Mass Rebuild

* Sun Jun 28 2015 sander85 <sander85> 0.804.0-1.mga6
+ Revision: 846923
- update to 0.804

* Wed Oct 15 2014 umeabot <umeabot> 0.802.0-4.mga5
+ Revision: 749316
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.802.0-3.mga5
+ Revision: 686056
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 0.802.0-2.mga4
+ Revision: 527264
- Mageia 4 Mass Rebuild

* Fri Jun 07 2013 jquelin <jquelin> 0.802.0-1.mga4
+ Revision: 439804
- update to 0.802

* Sun Jan 13 2013 umeabot <umeabot> 0.710.0-2.mga3
+ Revision: 372133
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Feb 06 2012 jquelin <jquelin> 0.710.0-1.mga2
+ Revision: 205183
- imported package perl-Proc-Fork

